@@ -67,7 +67,7 @@ typedef struct
 
   int size;
   GtkOrientation orientation;
-  
+
   GdkPixbuf *pb[7];
 
   GtkWidget *box;
@@ -78,7 +78,7 @@ typedef struct
   GtkTooltips *tooltips;
 
   XfcePanelPlugin *plugin;
-  
+
 } t_wavelan;
 
 static GdkPixbuf *
@@ -88,7 +88,7 @@ load_and_scale(const guint8 *data, int dstw, int dsth)
   int pb_w, pb_h;
 
   TRACE ("Entered load_and_scale");
-  
+
   pb = gdk_pixbuf_new_from_inline(-1, data, FALSE, NULL);
   pb_w = gdk_pixbuf_get_width(pb);
   pb_h = gdk_pixbuf_get_height(pb);
@@ -147,13 +147,13 @@ wavelan_load_pixbufs(t_wavelan *wavelan)
 
 static void
 wavelan_set_state(t_wavelan *wavelan, guint state)
-{  
+{
   /* this is OK, happens if this function is called too early */
   if (wavelan->pb[0] == NULL)
     return;
 
   TRACE ("Entered wavelan_set_state, state = %u", state);
-  
+
   if (state > STATE_LINK5)
     state = STATE_LINK5;
 
@@ -176,7 +176,7 @@ wavelan_timer(gpointer data)
   t_wavelan *wavelan = (t_wavelan *)data;
 
   TRACE ("Entered wavelan_timer");
-  
+
   if (wavelan->device != NULL) {
     int result;
 
@@ -220,7 +220,7 @@ wavelan_timer(gpointer data)
 
   /* activate new tooltip */
   if (tip != NULL) {
-    gtk_tooltips_set_tip(wavelan->tooltips, GTK_WIDGET (wavelan->plugin), 
+    gtk_tooltips_set_tip(wavelan->tooltips, GTK_WIDGET (wavelan->plugin),
                          tip, NULL);
     g_free(tip);
   }
@@ -233,7 +233,7 @@ static void
 wavelan_reset(t_wavelan *wavelan)
 {
   TRACE ("Entered wavelan_reset");
-  
+
   if (wavelan->timer_id != 0) {
     g_source_remove(wavelan->timer_id);
     wavelan->timer_id = 0;
@@ -260,9 +260,9 @@ wavelan_read_config(XfcePanelPlugin *plugin, t_wavelan *wavelan)
   char *file;
   XfceRc *rc;
   const char *s;
-  
+
   TRACE ("Entered wavelan_read_config");
-  
+
   if ((file = xfce_panel_plugin_lookup_rc_file (plugin)) != NULL)
   {
     rc = xfce_rc_simple_open (file, TRUE);
@@ -270,47 +270,46 @@ wavelan_read_config(XfcePanelPlugin *plugin, t_wavelan *wavelan)
 
     if (rc != NULL)
     {
-      if ((s = xfce_rc_read_entry (rc, "Interface", NULL)) != NULL) 
+      if ((s = xfce_rc_read_entry (rc, "Interface", NULL)) != NULL)
       {
         wavelan->interface = g_strdup (s);
       }
-      
+
       wavelan->autohide = xfce_rc_read_bool_entry (rc, "Autohide", FALSE);
       wavelan->autohide_missing = xfce_rc_read_bool_entry(rc, "AutohideMissing", FALSE);
     }
   }
-  
+
   wavelan_reset(wavelan);
 }
 
 static t_wavelan *
 wavelan_new(XfcePanelPlugin *plugin)
 {
-	t_wavelan *wavelan;
+  t_wavelan *wavelan;
   XfceScreenPosition screen_position;
-  int size;
-  
+
   TRACE ("Entered wavelan_new");
-  
-	wavelan = g_new0(t_wavelan, 1);
+
+  wavelan = g_new0(t_wavelan, 1);
 
   wavelan->autohide = FALSE;
   wavelan->autohide_missing = FALSE;
 
   wavelan->plugin = plugin;
-  
+
   wavelan->size = xfce_panel_plugin_get_size (plugin);
   screen_position = xfce_panel_plugin_get_screen_position (plugin);
   wavelan->orientation = xfce_panel_plugin_get_orientation (plugin);
- 
+
   wavelan->ebox = gtk_event_box_new();
   gtk_container_add (GTK_CONTAINER (plugin), wavelan->ebox);
-  
+
   if (xfce_screen_position_is_horizontal (screen_position))
       wavelan->box = xfce_hvbox_new (GTK_ORIENTATION_HORIZONTAL, FALSE, 0);
   else
       wavelan->box = xfce_hvbox_new (GTK_ORIENTATION_VERTICAL, FALSE, 0);
-  
+
   gtk_widget_show(wavelan->box);
   gtk_container_add (GTK_CONTAINER (wavelan->ebox), wavelan->box);
 
@@ -318,10 +317,10 @@ wavelan_new(XfcePanelPlugin *plugin)
   gtk_widget_show (wavelan->button);
 	gtk_box_pack_start(GTK_BOX (wavelan->box), wavelan->button, TRUE, TRUE, 0);*/
   gtk_widget_set_size_request (wavelan->box, -1, -1);
-  
+
   xfce_panel_plugin_add_action_widget (plugin, wavelan->box);
 
-  
+
   wavelan->image = gtk_image_new();
 	gtk_widget_show(wavelan->image);
   gtk_container_add (GTK_CONTAINER (wavelan->box), wavelan->image);
@@ -332,13 +331,13 @@ wavelan_new(XfcePanelPlugin *plugin)
   gtk_object_sink (GTK_OBJECT (wavelan->tooltips));
 
   wavelan_load_pixbufs(wavelan);
-  
+
   wavelan_read_config(plugin, wavelan);
 
   wavelan_set_state(wavelan, wavelan->state);
 
   gtk_widget_show_all(wavelan->ebox);
-  
+
   return(wavelan);
 }
 
@@ -348,7 +347,7 @@ wavelan_free(t_wavelan *wavelan)
   int n;
 
   TRACE ("Entered wavelan_free");
-  
+
   /* free tooltips */
   g_object_unref(G_OBJECT(wavelan->tooltips));
 
@@ -375,16 +374,16 @@ wavelan_write_config(XfcePanelPlugin *plugin, t_wavelan *wavelan)
 {
   char *file;
   XfceRc *rc;
-  
+
   TRACE ("Entered wavelan_write_config");
-  
+
   if (!(file = xfce_panel_plugin_save_location (plugin, TRUE)))
   {
     return;
   }
-   
+
   rc = xfce_rc_simple_open (file, FALSE);
-  
+
   g_free (file);
 
   if (!rc)
@@ -398,7 +397,7 @@ wavelan_write_config(XfcePanelPlugin *plugin, t_wavelan *wavelan)
   xfce_rc_write_bool_entry (rc, "AutohideMissing", wavelan->autohide_missing);
 
   xfce_rc_close(rc);
-  
+
 }
 
 static void
@@ -436,7 +435,7 @@ wavelan_autohide_changed(GtkToggleButton *button, t_wavelan *wavelan)
 }
 
 /* autohide on missing callback */
-static void 
+static void
 wavelan_autohide_missing_changed(GtkToggleButton *button, t_wavelan *wavelan)
 {
   TRACE ("Entered wavelan_autohide_missing_changed");
@@ -454,7 +453,7 @@ wavelan_query_interfaces (void)
   gint   n;
 
   TRACE ("Entered wavelan_query_interface");
-  
+
   fp = popen ("/sbin/ifconfig -a", "r");
   if (fp != NULL)
     {
@@ -495,10 +494,10 @@ wavelan_create_options (XfcePanelPlugin *plugin, t_wavelan *wavelan)
   GList     *interfaces, *lp;
 
   TRACE ("Entered wavelan_create_options");
-  
+
   dlg = gtk_dialog_new_with_buttons (_("Properties"),
               GTK_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (plugin))),
-              GTK_DIALOG_DESTROY_WITH_PARENT | 
+              GTK_DIALOG_DESTROY_WITH_PARENT |
               GTK_DIALOG_NO_SEPARATOR,
               GTK_STOCK_CLOSE, GTK_RESPONSE_OK,
               NULL);
@@ -509,7 +508,7 @@ wavelan_create_options (XfcePanelPlugin *plugin, t_wavelan *wavelan)
 
   g_signal_connect (dlg, "response", G_CALLBACK (wavelan_dialog_response),
                     wavelan);
-  
+
   gtk_container_set_border_width (GTK_CONTAINER (dlg), 2);
 
   header = xfce_create_header (NULL, _("Wavelan Plugin Options"));
@@ -518,16 +517,16 @@ wavelan_create_options (XfcePanelPlugin *plugin, t_wavelan *wavelan)
   gtk_widget_show (header);
   gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dlg)->vbox), header,
                       FALSE, TRUE, 0);
-              
+
   vbox = gtk_vbox_new(FALSE, 8);
   gtk_container_set_border_width (GTK_CONTAINER (vbox), 6);
   gtk_widget_show(vbox);
   gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dlg)->vbox), vbox,
                       TRUE, TRUE, 0);
-  
+
   hbox = gtk_hbox_new(FALSE, 8);
   gtk_widget_show(hbox);
-  
+
   label = gtk_label_new(_("Interface"));
   gtk_widget_show(label);
 
@@ -557,13 +556,13 @@ wavelan_create_options (XfcePanelPlugin *plugin, t_wavelan *wavelan)
   gtk_widget_show(autohide);
   gtk_box_pack_start(GTK_BOX(hbox), autohide, TRUE, TRUE, 1);
   gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 1);
-  
+
   hbox = gtk_hbox_new(FALSE, 2);
   gtk_widget_show(hbox);
   autohide_missing = gtk_check_button_new_with_label(_("Autohide when no hardware present"));
-  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(autohide_missing), 
+  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(autohide_missing),
       wavelan->autohide_missing);
-  g_signal_connect(autohide_missing, "toggled", 
+  g_signal_connect(autohide_missing, "toggled",
       G_CALLBACK(wavelan_autohide_missing_changed), wavelan);
   gtk_widget_show(autohide_missing);
   gtk_box_pack_start(GTK_BOX(hbox), autohide_missing, TRUE, TRUE, 1);
@@ -582,16 +581,16 @@ wavelan_create_options (XfcePanelPlugin *plugin, t_wavelan *wavelan)
   g_list_free (interfaces);
 
   gtk_widget_show (dlg);
-  
+
 }
 
 static void
-wavelan_set_screen_position (t_wavelan *wavelan, 
+wavelan_set_screen_position (t_wavelan *wavelan,
                              XfceScreenPosition position)
 {
 
   /* Do I really need anything here? */
-  
+
 }
 
 /*static void
@@ -599,7 +598,7 @@ wavelan_screen_position_changed (XfcePanelPlugin *plugin,
                                  XfceScreenPosition position,
                                  t_wavelan *wavelan)
 {
-    wavelan_set_screen_postion (wavelan, position); 
+    wavelan_set_screen_postion (wavelan, position);
 }*/
 
 static void
@@ -609,7 +608,7 @@ wavelan_orientation_changed (XfcePanelPlugin *plugin,
 {
     wavelan_set_orientation(wavelan, orientation);
 }
-  
+
 
 static void
 wavelan_size_changed(XfcePanelPlugin *plugin,
@@ -619,7 +618,7 @@ wavelan_size_changed(XfcePanelPlugin *plugin,
     wavelan_set_size(wavelan, size);
 }
 
-static void 
+static void
 wavelan_free_data (XfcePanelPlugin *plugin, t_wavelan *wavelan)
 {
   wavelan_free(wavelan);
@@ -640,9 +639,9 @@ wavelan_configure (XfcePanelPlugin *plugin, t_wavelan *wavelan)
 static void
 wavelan_construct (XfcePanelPlugin *plugin)
 {
-  
+
   TRACE ("Entered wavelan_construct");
-  
+
   t_wavelan *wavelan = wavelan_new(plugin);
 
 /*  g_signal_connect (plugin, "screen-position-changed",
@@ -653,20 +652,20 @@ wavelan_construct (XfcePanelPlugin *plugin)
 
   g_signal_connect (plugin, "size-changed",
                     G_CALLBACK (wavelan_size_changed), wavelan);
- 
+
   g_signal_connect (plugin, "free-data",
                     G_CALLBACK (wavelan_free_data), wavelan);
 
   g_signal_connect (plugin, "save",
                     G_CALLBACK (wavelan_save), wavelan);
-  
+
   xfce_panel_plugin_menu_show_configure (plugin);
   g_signal_connect (plugin, "configure-plugin",
                     G_CALLBACK (wavelan_configure), wavelan);
-  
+
   wavelan_set_screen_position (wavelan,
           xfce_panel_plugin_get_screen_position (plugin));
-  
+
 }
 
 XFCE_PANEL_PLUGIN_REGISTER_EXTERNAL(wavelan_construct);
